@@ -3,6 +3,7 @@ from pyhectiqlab.timer import RepeatedTimer
 
 import numpy as np
 import time
+import datetime as dt
 
 import logging
 logger = logging.getLogger('pyhectiqlab')
@@ -46,7 +47,7 @@ class MetricsManager():
     def add(self, key, value, step):
         if value is None:
             return
-        self.cache[key].append((float(step), float(value)))
+        self.cache[key].append((float(step), float(value), dt.datetime.timestamp(dt.datetime.utcnow())))
         if len(self.cache[key])>self.max_cache_length:
             if key in self.cache_last_push:
                 last_push_time = self.cache_last_push[key]
@@ -77,18 +78,21 @@ class MetricsManager():
         elif self.aggregate_metrics=="mean":
             k = [_[0] for _ in self.cache[key]]
             s = [_[1] for _ in self.cache[key]]
+            t = [_[2] for _ in self.cache[key]]
             if len(k) > 0:
-                self.push_method(key, [(float(np.max(k)), float(np.mean(s)))])
+                self.push_method(key, [(float(np.max(k)), float(np.mean(s)), float(np.mean(s)))])
         elif self.aggregate_metrics=="max":
             k = [_[0] for _ in self.cache[key]]
             s = [_[1] for _ in self.cache[key]]
+            t = [_[2] for _ in self.cache[key]]
             if len(k) > 0:
-                self.push_method(key, [(float(np.max(k)), float(np.max(s)))])
+                self.push_method(key, [(float(np.max(k)), float(np.max(s)), float(np.mean(s)))])
         elif self.aggregate_metrics=="sum":
             k = [_[0] for _ in self.cache[key]]
             s = [_[1] for _ in self.cache[key]]
+            t = [_[2] for _ in self.cache[key]]
             if len(k) > 0:
-                self.push_method(key, [(float(np.max(k)), float(np.sum(s)))])
+                self.push_method(key, [(float(np.max(k)), float(np.sum(s)), float(np.mean(t)))])
         self.cache[key] = []
 
     def __delete__(self):
