@@ -21,6 +21,8 @@ from functools import partial
 from typing import Optional, Union
 import tempfile
 import logging
+import traceback
+logger = logging.getLogger("pyhectiqlab")
 import shutil
 
 class Run():
@@ -78,7 +80,7 @@ class Run():
 
     def _setup_run(self):
         try:
-            assert self.run_view.get('status_code')==200, 'An error occured.'
+            assert self.run_view.get('status_code')==200, f'An error occured. {str(self.run_view)}'
 
             if self.run_view.get("is_new", False)==False:
                 print(f"Attaching to an existing run (ID :{self.run_view.get('p_id')}).")
@@ -87,21 +89,31 @@ class Run():
                 print("Warning::Run is read only because you are not the author of the run.")
                 self._read_only = True
                 self.setup_read_only()
+                return 
 
             if self.run_view.get('slug', None) is None:
-                print("An error occured while creating the run. Switching to read only mode.")
+                print("An error occured while creating the run. Verify the project is correctly spelled and make sure you have access to the project. Switching to read only mode with an empty run.")
                 if self.run_view.get('detail'):
                     print("Error: ", self.run_view.get('detail'))
                 self.setup_read_only()
                 return
         except:
-            print("An error occured while creating the run. Switching to read only mode.")
+            logger.debug(traceback.format_exc())
+            print("An error occured while creating the run. Verify the project is correctly spelled and make sure you have access to the project. Switching to read only mode with an empty run.")
             if self.run_view.get('detail'):
                 print("Error: ", self.run_view.get('detail'))
+            else:
+                if self.run_view.get("status_code")==400:
+                    print("You got an error 400 without any details. The server may be unreachable (check your internet connection). Please report this problem at https://github.com/HectiqAI/lab/discussions")
+                else:
+                    print(f"Error {self.run_view.get('status_code')} without details. Please report this problem at https://github.com/HectiqAI/lab/discussions")
+
             self.setup_read_only()
+            return 
 
         self.metrics_manager = MetricsManager(push_method=self._push_metrics)
         self.logs_buffer = Buffer(push_method=self._push_logs)
+        self.add_log_stream("pyhectiqlab", level=logging.INFO)
 
     def user_is_not_logged(self):
         print("User not authentificated. Use `hectiqlab add-profile` in command line.")
@@ -129,7 +141,7 @@ class Run():
         filename = os.path.basename(filepath)
         num_bytes = os.path.getsize(filepath)
         args = (self._id, self._project_path, filename, filepath, name, num_bytes, step)
-        return self.events_manager.add_event("add_artifact", args, async_method=bool(1-wait_response))
+        self.events_manager.add_event("add_artifact", args, async_method=bool(1-wait_response))
 
     @write_method
     @action_method
@@ -155,14 +167,14 @@ class Run():
         meta = mlmodel_info_at_path(dirpath)
         assert meta is not None, f'Could not find the mlmodel at {dirpath}'
 
-        print(f"{meta.get('name')} - {meta.get('version')}")
+        logger.info(f"Found {meta.get('name')} - {meta.get('version')}")
         args = (self._id, self._project_path, meta.get('name'), meta.get('version'))
         self.events_manager.add_event("log_mlmodel", args)
         return
         
     @write_method
     @action_method        
-    def add_mlmodel(self, source_path: str, name: str, version: str = None, short_description: str = None,
+    def add_mlmodel(self, source_path: str, name: str, version: str = None, description: str = None,
                 push_dir: bool = False):
         """Add a mlmodel.
 
@@ -171,7 +183,7 @@ class Run():
         version: Version in format '{major}.{minor}.{micro}' (e.g., 1.2.0). If None, 
             the version 1.0.0 is assigned or an increment of minor of the latest version of the
             model with this name (e.g. 1.3.3 -> 1.4.0)
-        short_description: Short description.
+        description: Short description.
         push_dir: Must be set to True if the source_path is a directory
         """
         mlmodel = ops_upload_mlmodel(source_path=source_path, 
@@ -179,7 +191,7 @@ class Run():
              run_id=self._id,
              project_path=self._project_path,
              version=version,
-             short_description=short_description,
+             short_description=description,
              push_dir=push_dir)
         if mlmodel is not None:
             self.add_mlmodel_usage(mlmodel.get('name'), version=mlmodel.get('version'))
@@ -206,7 +218,7 @@ class Run():
         
     @write_method
     @action_method
-    def add_dataset(self, source_path: str, name: str, version: str = None, short_description: str = None,
+    def add_dataset(self, source_path: str, name: str, version: str = None, description: str = None,
                 push_dir: bool = False):
         """Add a dataset.
 
@@ -215,7 +227,7 @@ class Run():
         version: Version in format '{major}.{minor}.{micro}' (e.g., 1.2.0). If None, 
             the version 1.0.0 is assigned or an increment of minor of the latest version of the
             dataset with this name (e.g. 1.3.3 -> 1.4.0)
-        short_description: Short description.
+        description: Short description.
         push_dir: Must be set to True if the source_path is a directory
         """
         dataset = ops_upload_dataset(source_path=source_path, 
@@ -223,7 +235,7 @@ class Run():
              run_id=self._id, 
              project_path=self._project_path,
              version=version,
-             short_description=short_description,
+             short_description=description,
              push_dir=push_dir)
         if dataset is not None:
             self.add_dataset_usage(dataset.get('name'), version=dataset.get('version'))
@@ -252,7 +264,7 @@ class Run():
         meta = dataset_info_at_path(dirpath)
         assert meta is not None, f'Could not find the dataset at {dirpath}'
 
-        print(f"{meta.get('name')} - {meta.get('version')}")
+        logger.info(f"{meta.get('name')} - {meta.get('version')}")
         args = (self._id, self._project_path, meta.get('name'), meta.get('version'))
         self.events_manager.add_event("log_dataset", args)
         return
@@ -325,7 +337,7 @@ class Run():
 
     @write_method
     @action_method
-    def add_metrics(self, key: 'str', value: float, step: float):
+    def add_metrics(self, key: 'str', step: float, value: float):
         """Add a metrics. The metrics is saved even if there already exists a value
         for the same key and step. 
 
@@ -338,11 +350,11 @@ class Run():
 
     @write_method
     @action_method
-    def add_tag(self, name: str, description: str = None, color: str = None):
+    def add_tag(self, name: str, color: str = None):
         """Add tag to a run. If the tag does not already exists by this name,
         a new tag is created with the given description and color.
         """
-        args = (self._id, self._project_path, name, description, color)
+        args = (self._id, self._project_path, name, color)
         self.events_manager.add_event("add_tag", args)
 
     @write_method
@@ -480,9 +492,8 @@ class Run():
             else:
                 self.add_tag(name="failed")
                 self.failed()
-            
-            logger = self.add_log_stream(level=50, format="%(asctime)s - %(levelname)s - %(message)s")
-            logger.critical("Automatic exception handler", exc_info=(exc_type, exc_value, exc_traceback))
+            l = self.add_log_stream("pyhectiqlab", level=logging.ERROR)
+            l.critical("Automatic exception handler", exc_info=(exc_type, exc_value, exc_traceback))
 
             # Flush cache before leaving
             self.logs_buffer.flush_cache()
@@ -494,15 +505,19 @@ class Run():
 
     def add_log_stream(self, logger_name: Optional[str] = None, 
                         format: Optional[Union[str, "logging.Formatter"]] = "%(asctime)s - %(levelname)s - %(message)s", 
-                        level: Optional[int] = 1):
+                        level: Optional[int] = 30):
         """Start tailing the logs on a logger name.
         If logger_name is None, the default __name__ will be taken and
         you may use the returned logger.
         """
         if self.dry_mode or self.read_only:
-            print('A logger is returned but the logs are not stored because you are in a dry (offline) mode.')
+            logger.error(f"A logger named {logger_name} is returned but the logs aren't saved because you are in a read-only mode.")
             return logging.getLogger(logger_name)
         
+        if (logger_name is None or logger_name=="pyhectiqlab")and level<10:
+            logger.error(f"Cannot assign a level {level} (<10) on root logger. Use a `logger_name` to specify a different stream. Level is switch to 10.")
+            level = 10
+
         # Start recording
         self.logs_buffer.start(key=logger_name)
 
@@ -511,17 +526,19 @@ class Run():
             func = partial(self.logs_buffer.add, key=logger_name)
             log_recorder = LogHandler(func)
             log_recorder.set_name("hectiqlab")
+            log_recorder.set_name("hectiqlab")
+            log_recorder.setLevel(level)
             console = logging.StreamHandler()
             console.setLevel(level)
-            logger = logging.getLogger(logger_name)
-            logger.setLevel(level)
-            logger.addHandler(log_recorder)
+            log = logging.getLogger(logger_name)
+            log.setLevel(level)
+            log.addHandler(log_recorder)
             if isinstance(format, str):
                 formatter = logging.Formatter(format)
             else:
                 formatter = format
             log_recorder.setFormatter(formatter)
-            self.log_streams[logger_name] = logger
+            self.log_streams[logger_name] = log
 
         return self.log_streams[logger_name]
 
@@ -530,10 +547,10 @@ class Run():
         """
         self.logs_buffer.stop(key=logger_name)
         if logger_name in self.log_streams:
-            logger = self.log_streams[logger_name]
-            for handler in logger.handlers:
+            log = self.log_streams[logger_name]
+            for handler in log.handlers:
                 if handler.get_name()=="hectiqlab":
-                    logger.removeHandler(handler)
+                    log.removeHandler(handler)
 
         self.log_streams.pop(logger_name, None)
 
@@ -582,8 +599,7 @@ class Run():
         return author.get('firstname') + ' ' + author.get('lastname')
         
     def __str__(self):
-        # print(self.run_view)
-        pad = 9
+        pad = 8
         project = self.run_view.get('project', {})
         path = f"/{project.get('path')}/runs/{self.run_view.get('slug')}"
         return f"<Run {self.run_view.get('p_id')} {self.run_view.get('slug')}>"\
